======
hxnfly
======

Specify PPMac host name or address by setting an environment variable PPMAC_HOST.

Shell script::

  export PPMAC_HOST=<host-name-or-ip>

Python script::

  os.environ["PPMAC_HOST"] = "<host-name-or-ip>"
